@@ -669,13 +669,13 @@ class DirectoryDistributive(Distributive):
         if not self.system_mounted:
             self.clVars = DataVarsInstall()
             # Если в режиме EFI, добавить раздел efivarfs
-            if self.clVars.GetBool('install.os_install_uefi_set'):
-                self.data.append(
-                {'name': 'efivars',
-                 'type': 'efivarfs',
-                 'target': 'sys/firmware/efi/efivars',
-                 'source': 'efivarfs'}
-                )            
+            if self.clVars.GetBool('main.os_uefi_set'):
+                efi_data = {'name': 'efivars',
+                            'type': 'efivarfs',
+                            'target': 'sys/firmware/efi/efivars',
+                            'source': 'efivarfs'}
+                if not efi_data in self.data:
+                    self.data.append(efi_data)
             for obj in (x for x in self.data if x['name'] not in skip):
                 target_path = path.join(self.directory, obj['target'])
                 if obj['type'] == 'bind':
